@@ -10,7 +10,7 @@ cs *cs_kroneckerI(const cs *A, int nI){
     cm = am*nI; cn = an*nI; cnz = anz*nI;
     C = cs_spalloc (cm, cn, cnz, 1, 0) ;	 /* allocate result */
 
-    if (!C ) error("cs_directsum out of memory");  
+    if (!C ) Rf_error("cs_kroneckerI out of memory");  
   //  if (!C ) return (cs_done (C, NULL, NULL, 0));  
 
     Cp = C->p ; Ci = C->i ; Cx = C->x ;   
